@@ -1,6 +1,7 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*-
  *
  * Copyright (C) 2012,2013,2015 Colin Walters <walters@verbum.org>.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,8 +26,10 @@
 G_BEGIN_DECLS
 
 #include <glnx-macros.h>
+#include <glnx-missing.h>
 #include <glnx-local-alloc.h>
 #include <glnx-backport-autocleanups.h>
+#include <glnx-backport-testutils.h>
 #include <glnx-backports.h>
 #include <glnx-lockfile.h>
 #include <glnx-errors.h>
