@@ -26,7 +26,6 @@
 #include "ot-admin-builtins.h"
 #include "ot-admin-functions.h"
 #include "ot-builtins.h"
-#include "ot-main.h"
 
 #include <glib/gi18n.h>
 
@@ -39,8 +38,18 @@ static OstreeCommand admin_subcommands[] = {
     "Checkout revision REFSPEC as the new default deployment" },
   { "finalize-staged", OSTREE_BUILTIN_FLAG_NO_REPO | OSTREE_BUILTIN_FLAG_HIDDEN,
     ot_admin_builtin_finalize_staged, "Internal command to run at shutdown time" },
+  { "lock-finalization", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_lock_finalization,
+    "Change the finalization locking state of the staged deployment" },
   { "boot-complete", OSTREE_BUILTIN_FLAG_NO_REPO | OSTREE_BUILTIN_FLAG_HIDDEN,
     ot_admin_builtin_boot_complete, "Internal command to run at boot after an update was applied" },
+#ifdef HAVE_SOFT_REBOOT
+  { "impl-prepare-soft-reboot", OSTREE_BUILTIN_FLAG_NO_REPO | OSTREE_BUILTIN_FLAG_HIDDEN,
+    ot_admin_builtin_impl_prepare_soft_reboot, "Internal command to prepare soft reboot" },
+  { "prepare-soft-reboot", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_prepare_soft_reboot,
+    "Prepare deployment for soft-reboot" },
+#endif
+  { "state-overlay", OSTREE_BUILTIN_FLAG_NO_REPO | OSTREE_BUILTIN_FLAG_HIDDEN,
+    ot_admin_builtin_state_overlay, "Internal command to assemble a state overlay" },
   { "init-fs", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_init_fs,
     "Initialize a root filesystem" },
   { "instutil", OSTREE_BUILTIN_FLAG_NO_REPO | OSTREE_BUILTIN_FLAG_HIDDEN, ot_admin_builtin_instutil,
@@ -50,7 +59,10 @@ static OstreeCommand admin_subcommands[] = {
   { "stateroot-init", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_os_init,
     "Initialize empty state for given operating system" },
   { "pin", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_pin,
-    "Change the \"pinning\" state of a deployment" },
+    "Change the \"pinning\" state of a deployment, INDEX can be >= 0 or one of booted, pending or "
+    "rollback strings" },
+  { "post-copy", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_post_copy,
+    "Update the repo and deployments as needed after a copy" },
   { "set-origin", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_set_origin,
     "Set Origin and create a new origin file" },
   { "status", OSTREE_BUILTIN_FLAG_NO_REPO, ot_admin_builtin_status, "List deployments" },
@@ -79,7 +91,7 @@ ostree_admin_option_context_new_with_commands (void)
     {
       if ((command->flags & OSTREE_BUILTIN_FLAG_HIDDEN) == 0)
         {
-          g_string_append_printf (summary, "\n  %-19s", command->name);
+          g_string_append_printf (summary, "\n  %-25s", command->name);
           if (command->description != NULL)
             g_string_append_printf (summary, "%s", command->description);
         }
