@@ -14,9 +14,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <https://www.gnu.org/licenses/>.
  */
 
 #pragma once
@@ -25,19 +23,12 @@
 
 G_BEGIN_DECLS
 
-gboolean
-ot_add_cookie_at (int dfd, const char *jar_path,
-                  const char *domain, const char *path,
-                  const char *name, const char *value,
-                  GError **error);
+gboolean ot_add_cookie_at (int dfd, const char *jar_path, const char *domain, const char *path,
+                           const char *name, const char *value, GError **error);
 
-gboolean
-ot_delete_cookie_at (int dfd, const char *jar_path,
-                     const char *domain, const char *path,
-                     const char *name,
-                     GError **error);
+gboolean ot_delete_cookie_at (int dfd, const char *jar_path, const char *domain, const char *path,
+                              const char *name, GError **error);
 
-gboolean
-ot_list_cookies_at (int dfd, const char *jar_path, GError **error);
+gboolean ot_list_cookies_at (int dfd, const char *jar_path, GError **error);
 
 G_END_DECLS
