@@ -28,16 +28,12 @@ G_BEGIN_DECLS
 
 gboolean ot_test_run_libtest (const char *cmd, GError **error);
 
-OstreeRepo *ot_test_setup_repo (GCancellable *cancellable,
-                                GError **error);
+OstreeRepo *ot_test_setup_repo (GCancellable *cancellable, GError **error);
 
-gboolean ot_check_relabeling (gboolean *can_relabel,
-                              GError  **error);
+gboolean ot_check_relabeling (gboolean *can_relabel, GError **error);
 
-gboolean ot_check_user_xattrs (gboolean *has_user_xattrs,
-                               GError  **error);
+gboolean ot_check_user_xattrs (gboolean *has_user_xattrs, GError **error);
 
-OstreeSysroot *ot_test_setup_sysroot (GCancellable *cancellable,
-                                      GError **error);
+OstreeSysroot *ot_test_setup_sysroot (GCancellable *cancellable, GError **error);
 
 G_END_DECLS
