@@ -13,9 +13,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# License along with this library. If not, see <https://www.gnu.org/licenses/>.
 
 from __future__ import division
 from __future__ import print_function
@@ -45,10 +43,6 @@ with open('repo/config', 'a') as f:
     # it's simpler, and we don't need xattr coverage for this
     f.write('disable-xattrs=true\n')
 
-    # Make any locking errors fail quickly instead of blocking the test
-    # for 30 seconds.
-    f.write('lock-timeout-secs=5\n')
-
 def commit(v):
     tdir='tree{}'.format(v)
     cmd = ['ostree', '--repo=repo', 'commit', '--fsync=0', '-b', tdir, '--tree=dir='+tdir]
