@@ -15,9 +15,7 @@
 # Lesser General Public License for more details.
 #
 # You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the
-# Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-# Boston, MA 02111-1307, USA.
+# License along with this library. If not, see <https://www.gnu.org/licenses/>.
 #
 # Authors:
 #  - Philip Withnall <withnall@endlessm.com>
@@ -26,6 +24,7 @@ set -euo pipefail
 
 . $(dirname $0)/libtest.sh
 
+skip_without_sudo
 SUDO="sudo --non-interactive"
 
 # Skip the test if a well-known USB stick is not available.
